@@ -17,7 +17,7 @@ INSTALLED_APPS += (
 CACHES['default']['KEY_PREFIX'] = '_'.join((PROJECT_NAME, 'PRJ'))
 
 # Sessions
-SESSION_ENGINE = "django.contrib.sessions.backends.cache"
+# SESSION_ENGINE = "django.contrib.sessions.backends.cache"
 
 # Templates cache
 TEMPLATE_LOADERS = (
