@@ -1,6 +1,6 @@
 #!/bin/bash
 
-source {{ project_servicedir }}/.bsfl
+source $(dirname $0)/utils.sh
 
 # Check mysql installed.
 check_program mysql
